package
module
Version:
v0.0.0-...-9d0ad23
Opens a new window with list of versions in this module.
Published: Apr 23, 2025
License: GPL-3.0
Opens a new window with license information.
Imports: 4
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type UserInput struct {
Username string `json:"username" binding:"required"`
Password string `json:"password" binding:"required"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.